@@ -11,6 +11,16 @@ from .error import (BasePathError, ProjectExistsError, ProjectDataMissingError,
         ProjectMissingError, TemplateDataMissingError, SystemDataMissingError,
         GitExistsError, GitMissingError)
 
+SHUTIL_ARCHIVE_FORMATS = [ar[0] for ar in shutil.get_archive_formats()]
+_suffix_map_helper = {
+        '.tar': 'tar',
+        '.tar.bz': 'bztar',
+        '.tar.gz': 'gztar',
+        '.tar.xz': 'xztar',
+        '.zip': 'zip'
+        }
+SHUTIL_ARCHIVE_SUFFIX_MAP = {k:v for k, v in _suffix_map_helper.items()
+        if v in SHUTIL_ARCHIVE_FORMATS}
 
 def _constant(f):
     def fset(self, value):
@@ -31,11 +41,11 @@ def toml_dump(path_obj, dct):
 class _ConfigPath:
     @_constant
     def system(self):
-        return XDG_DATA_HOME / 'texproject' / 'config' / 'tpr_config.toml'
+        return XDG_CONFIG_HOME / 'texproject' / 'system.toml'
 
     @_constant
     def user(self):
-        return XDG_CONFIG_HOME / 'texproject' / 'config.toml'
+        return XDG_CONFIG_HOME / 'texproject' / 'user.toml'
 
 
 CONFIG_PATH = _ConfigPath()
@@ -220,7 +230,7 @@ class ProjectPath:
 
     @_constant
     def gitfiles(self):
-        return (self.git_home, self.github_home)
+        return (self.git_home, self.github_home, self.gitignore)
 
     @_constant
     def minimal_gitfiles(self):
